@@ -14,8 +14,9 @@ from django.db import models
 from django.db.models import Count, Exists, OuterRef, Sum
 from django.db.models.fields import Field
 from django.db.models.lookups import StartsWith
+from django.template.defaultfilters import striptags
 from django.urls import reverse
-from django.utils.functional import cached_property
+from django.utils.functional import SimpleLazyObject, cached_property
 from django.utils.html import strip_tags
 from django.utils.safestring import mark_safe
 from django.utils.translation import get_language
@@ -23,6 +24,7 @@ from django.utils.translation import gettext_lazy as _
 from django.utils.translation import pgettext_lazy
 from treebeard.mp_tree import MP_Node
 
+from oscar.core.decorators import deprecated
 from oscar.core.loading import get_class, get_classes, get_model
 from oscar.core.utils import slugify
 from oscar.core.validators import non_python_keyword
@@ -127,6 +129,8 @@ class AbstractCategory(MP_Node):
 
     name = models.CharField(_('Name'), max_length=255, db_index=True)
     description = models.TextField(_('Description'), blank=True)
+    meta_title = models.CharField(_('Meta title'), max_length=255, blank=True, null=True)
+    meta_description = models.TextField(_('Meta description'), blank=True, null=True)
     image = models.ImageField(_('Image'), upload_to='categories', blank=True,
                               null=True, max_length=255)
     slug = SlugField(_('Slug'), max_length=255, db_index=True)
@@ -234,6 +238,12 @@ class AbstractCategory(MP_Node):
             else:
                 node.set_ancestors_are_public()
 
+    def get_meta_title(self):
+        return self.meta_title or self.name
+
+    def get_meta_description(self):
+        return self.meta_description or striptags(self.description)
+
     def get_ancestors_and_self(self):
         """
         Gets ancestors and includes itself. Use treebeard's get_ancestors
@@ -368,6 +378,8 @@ class AbstractProduct(models.Model):
                              max_length=255, blank=True)
     slug = models.SlugField(_('Slug'), max_length=255, unique=False)
     description = models.TextField(_('Description'), blank=True)
+    meta_title = models.CharField(_('Meta title'), max_length=255, blank=True, null=True)
+    meta_description = models.TextField(_('Meta description'), blank=True, null=True)
 
     #: "Kind" of product, e.g. T-Shirt, Book, etc.
     #: None for child products, they inherit their parent's product class
@@ -434,7 +446,7 @@ class AbstractProduct(models.Model):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.attr = ProductAttributesContainer(product=self)
+        self.attr = SimpleLazyObject(lambda: ProductAttributesContainer(product=self))
 
     def __str__(self):
         if self.title:
@@ -598,7 +610,7 @@ class AbstractProduct(models.Model):
         """
         Return a string of all of a product's attributes
         """
-        attributes = self.attribute_values.all()
+        attributes = self.get_attribute_values()
         pairs = [attribute.summary() for attribute in attributes]
         return ", ".join(pairs)
 
@@ -612,6 +624,20 @@ class AbstractProduct(models.Model):
         return title
     get_title.short_description = pgettext_lazy("Product title", "Title")
 
+    def get_meta_title(self):
+        title = self.meta_title
+        if not title and self.is_child:
+            title = self.parent.meta_title
+        return title or self.get_title()
+    get_meta_title.short_description = pgettext_lazy("Product meta title", "Meta title")
+
+    def get_meta_description(self):
+        meta_description = self.meta_description
+        if not meta_description and self.is_child:
+            meta_description = self.parent.meta_description
+        return meta_description or striptags(self.description)
+    get_meta_description.short_description = pgettext_lazy("Product meta description", "Meta description")
+
     def get_product_class(self):
         """
         Return a product's item class. Child products inherit their parent's.
@@ -642,6 +668,16 @@ class AbstractProduct(models.Model):
             return self.categories
     get_categories.short_description = _("Categories")
 
+    def get_attribute_values(self):
+        attribute_values = self.attribute_values.all()
+        if self.is_child:
+            parent_attribute_values = self.parent.attribute_values.exclude(
+                attribute__code__in=attribute_values.values("attribute__code")
+            )
+            return attribute_values | parent_attribute_values
+
+        return attribute_values
+
     # Images
 
     def get_missing_image(self):
@@ -1180,22 +1216,36 @@ class AbstractOption(models.Model):
     This is not the same as an 'attribute' as options do not have a fixed value
     for a particular item.  Instead, option need to be specified by a customer
     when they add the item to their basket.
-    """
-    name = models.CharField(_("Name"), max_length=128)
-    code = AutoSlugField(_("Code"), max_length=128, unique=True,
-                         populate_from='name')
 
-    REQUIRED, OPTIONAL = ('Required', 'Optional')
+    The `type` of the option determines the form input that will be used to
+    collect the information from the customer, and the `required` attribute
+    determines whether a value must be supplied in order to add the item to the basket.
+    """
+
+    # Option types
+    TEXT = "text"
+    INTEGER = "integer"
+    FLOAT = "float"
+    BOOLEAN = "boolean"
+    DATE = "date"
+
     TYPE_CHOICES = (
-        (REQUIRED, _("Required - a value for this option must be specified")),
-        (OPTIONAL, _("Optional - a value for this option can be omitted")),
+        (TEXT, _("Text")),
+        (INTEGER, _("Integer")),
+        (BOOLEAN, _("True / False")),
+        (FLOAT, _("Float")),
+        (DATE, _("Date")),
     )
-    type = models.CharField(_("Status"), max_length=128, default=REQUIRED,
-                            choices=TYPE_CHOICES)
+
+    name = models.CharField(_("Name"), max_length=128, db_index=True)
+    code = AutoSlugField(_("Code"), max_length=128, unique=True, populate_from='name')
+    type = models.CharField(_("Type"), max_length=255, default=TEXT, choices=TYPE_CHOICES)
+    required = models.BooleanField(_("Is this option required?"), default=False)
 
     class Meta:
         abstract = True
         app_label = 'catalogue'
+        ordering = ['name']
         verbose_name = _("Option")
         verbose_name_plural = _("Options")
 
@@ -1203,8 +1253,9 @@ class AbstractOption(models.Model):
         return self.name
 
     @property
+    @deprecated
     def is_required(self):
-        return self.type == self.REQUIRED
+        return self.required
 
 
 class MissingProductImage(object):
@@ -1241,13 +1292,11 @@ class MissingProductImage(object):
                     "Please copy/symlink the "
                     "'missing image' image at %s into your MEDIA_ROOT at %s. "
                     "This exception was raised because Oscar was unable to "
-                    "symlink it for you.") % (media_file_path,
-                                              settings.MEDIA_ROOT))
+                    "symlink it for you.") % (static_file_path, settings.MEDIA_ROOT))
             else:
                 logging.info((
                     "Symlinked the 'missing image' image at %s into your "
-                    "MEDIA_ROOT at %s") % (media_file_path,
-                                           settings.MEDIA_ROOT))
+                    "MEDIA_ROOT at %s") % (static_file_path, settings.MEDIA_ROOT))
 
 
 class AbstractProductImage(models.Model):
