@@ -5,11 +5,12 @@ from django.http import HttpResponseRedirect
 from django.shortcuts import get_object_or_404, redirect
 from django.template.loader import render_to_string
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.views import generic
 from django_tables2 import SingleTableMixin, SingleTableView
 
-from oscar.core.loading import get_classes, get_model
+from oscar.core.decorators import deprecated
+from oscar.core.loading import get_class, get_classes, get_model
 from oscar.views.generic import ObjectLookupView
 
 (ProductForm,
@@ -18,7 +19,8 @@ from oscar.views.generic import ObjectLookupView
  ProductClassForm,
  CategoryForm,
  StockAlertSearchForm,
- AttributeOptionGroupForm) \
+ AttributeOptionGroupForm,
+ OptionForm) \
     = get_classes('dashboard.catalogue.forms',
                   ('ProductForm',
                    'ProductClassSelectForm',
@@ -26,7 +28,8 @@ from oscar.views.generic import ObjectLookupView
                    'ProductClassForm',
                    'CategoryForm',
                    'StockAlertSearchForm',
-                   'AttributeOptionGroupForm'))
+                   'AttributeOptionGroupForm',
+                   'OptionForm'))
 (StockRecordFormSet,
  ProductCategoryFormSet,
  ProductImageFormSet,
@@ -40,10 +43,10 @@ from oscar.views.generic import ObjectLookupView
                    'ProductRecommendationFormSet',
                    'ProductAttributesFormSet',
                    'AttributeOptionFormSet'))
-ProductTable, CategoryTable, AttributeOptionGroupTable \
+ProductTable, CategoryTable, AttributeOptionGroupTable, OptionTable \
     = get_classes('dashboard.catalogue.tables',
                   ('ProductTable', 'CategoryTable',
-                   'AttributeOptionGroupTable'))
+                   'AttributeOptionGroupTable', 'OptionTable'))
 (PopUpWindowCreateMixin,
  PopUpWindowUpdateMixin,
  PopUpWindowDeleteMixin) \
@@ -51,6 +54,7 @@ ProductTable, CategoryTable, AttributeOptionGroupTable \
                   ('PopUpWindowCreateMixin',
                    'PopUpWindowUpdateMixin',
                    'PopUpWindowDeleteMixin'))
+PartnerProductFilterMixin = get_class('dashboard.catalogue.mixins', 'PartnerProductFilterMixin')
 Product = get_model('catalogue', 'Product')
 Category = get_model('catalogue', 'Category')
 ProductImage = get_model('catalogue', 'ProductImage')
@@ -60,8 +64,10 @@ StockRecord = get_model('partner', 'StockRecord')
 StockAlert = get_model('partner', 'StockAlert')
 Partner = get_model('partner', 'Partner')
 AttributeOptionGroup = get_model('catalogue', 'AttributeOptionGroup')
+Option = get_model('catalogue', 'Option')
 
 
+@deprecated
 def filter_products(queryset, user):
     """
     Restrict the queryset to products the given user has access to.
@@ -75,21 +81,21 @@ def filter_products(queryset, user):
     return queryset.filter(stockrecords__partner__users__pk=user.pk).distinct()
 
 
-class ProductListView(SingleTableView):
+class ProductListView(PartnerProductFilterMixin, SingleTableView):
 
     """
     Dashboard view of the product list.
     Supports the permission-based dashboard.
     """
 
-    template_name = 'dashboard/catalogue/product_list.html'
+    template_name = 'oscar/dashboard/catalogue/product_list.html'
     form_class = ProductSearchForm
     productclass_form_class = ProductClassSelectForm
     table_class = ProductTable
     context_table_name = 'products'
 
     def get_context_data(self, **kwargs):
-        ctx = super(ProductListView, self).get_context_data(**kwargs)
+        ctx = super().get_context_data(**kwargs)
         ctx['form'] = self.form
         ctx['productclass_form'] = self.productclass_form_class()
         return ctx
@@ -103,32 +109,28 @@ class ProductListView(SingleTableView):
         if 'recently_edited' in self.request.GET:
             kwargs.update(dict(orderable=False))
 
-        table = super(ProductListView, self).get_table(**kwargs)
+        table = super().get_table(**kwargs)
         table.caption = self.get_description(self.form)
         return table
 
     def get_table_pagination(self, table):
-        return dict(per_page=20)
-
-    def filter_queryset(self, queryset):
-        """
-        Apply any filters to restrict the products that appear on the list
-        """
-        return filter_products(queryset, self.request.user)
+        return dict(per_page=settings.OSCAR_DASHBOARD_ITEMS_PER_PAGE)
 
     def get_queryset(self):
         """
         Build the queryset for this list
         """
-        queryset = Product.browsable.base_queryset()
+        queryset = Product.objects.browsable_dashboard().base_queryset()
         queryset = self.filter_queryset(queryset)
         queryset = self.apply_search(queryset)
         return queryset
 
     def apply_search(self, queryset):
         """
-        Filter the queryset and set the description according to the search
-        parameters given
+        Search through the filtered queryset.
+
+        We must make sure that we don't return search results that the user is not allowed
+        to see (see filter_queryset).
         """
         self.form = self.form_class(self.request.GET)
 
@@ -139,16 +141,23 @@ class ProductListView(SingleTableView):
 
         if data.get('upc'):
             # Filter the queryset by upc
-            # If there's an exact match, return it, otherwise return results
-            # that contain the UPC
-            matches_upc = Product.objects.filter(upc=data['upc'])
+            # For usability reasons, we first look at exact matches and only return
+            # them if there are any. Otherwise we return all results
+            # that contain the UPC.
+
+            # Look up all matches (child products, products not allowed to access) ...
+            matches_upc = Product.objects.filter(upc__iexact=data['upc'])
+
+            # ... and use that to pick all standalone or parent products that the user is
+            # allowed to access.
             qs_match = queryset.filter(
-                Q(id__in=matches_upc.values('id')) |
-                Q(id__in=matches_upc.values('parent_id')))
+                Q(id__in=matches_upc.values('id')) | Q(id__in=matches_upc.values('parent_id')))
 
             if qs_match.exists():
+                # If there's a direct UPC match, return just that.
                 queryset = qs_match
             else:
+                # No direct UPC match. Let's try the same with an icontains search.
                 matches_upc = Product.objects.filter(upc__icontains=data['upc'])
                 queryset = queryset.filter(
                     Q(id__in=matches_upc.values('id')) | Q(id__in=matches_upc.values('parent_id')))
@@ -182,7 +191,7 @@ class ProductCreateRedirectView(generic.RedirectView):
             return self.get_invalid_product_class_url()
 
 
-class ProductCreateUpdateView(generic.UpdateView):
+class ProductCreateUpdateView(PartnerProductFilterMixin, generic.UpdateView):
     """
     Dashboard view that is can both create and update products of all kinds.
     It can be used in three different ways, each of them with a unique URL
@@ -198,7 +207,7 @@ class ProductCreateUpdateView(generic.UpdateView):
     Supports the permission-based dashboard.
     """
 
-    template_name = 'dashboard/catalogue/product_update.html'
+    template_name = 'oscar/dashboard/catalogue/product_update.html'
     model = Product
     context_object_name = 'product'
 
@@ -208,15 +217,18 @@ class ProductCreateUpdateView(generic.UpdateView):
     recommendations_formset = ProductRecommendationFormSet
     stockrecord_formset = StockRecordFormSet
 
+    creating = False
+    parent = None
+
     def __init__(self, *args, **kwargs):
-        super(ProductCreateUpdateView, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.formsets = {'category_formset': self.category_formset,
                          'image_formset': self.image_formset,
                          'recommended_formset': self.recommendations_formset,
                          'stockrecord_formset': self.stockrecord_formset}
 
     def dispatch(self, request, *args, **kwargs):
-        resp = super(ProductCreateUpdateView, self).dispatch(
+        resp = super().dispatch(
             request, *args, **kwargs)
         return self.check_objects_or_redirect() or resp
 
@@ -237,7 +249,7 @@ class ProductCreateUpdateView(generic.UpdateView):
         """
         Filter products that the user doesn't have permission to update
         """
-        return filter_products(Product.objects.all(), self.request.user)
+        return self.filter_queryset(Product.objects.all())
 
     def get_object(self, queryset=None):
         """
@@ -266,13 +278,13 @@ class ProductCreateUpdateView(generic.UpdateView):
 
             return None  # success
         else:
-            product = super(ProductCreateUpdateView, self).get_object(queryset)
+            product = super().get_object(queryset)
             self.product_class = product.get_product_class()
             self.parent = product.parent
             return product
 
     def get_context_data(self, **kwargs):
-        ctx = super(ProductCreateUpdateView, self).get_context_data(**kwargs)
+        ctx = super().get_context_data(**kwargs)
         ctx['product_class'] = self.product_class
         ctx['parent'] = self.parent
         ctx['title'] = self.get_page_title()
@@ -300,7 +312,7 @@ class ProductCreateUpdateView(generic.UpdateView):
                     'parent_product': self.parent.title}
 
     def get_form_kwargs(self):
-        kwargs = super(ProductCreateUpdateView, self).get_form_kwargs()
+        kwargs = super().get_form_kwargs()
         kwargs['product_class'] = self.product_class
         kwargs['parent'] = self.parent
         return kwargs
@@ -365,6 +377,10 @@ class ProductCreateUpdateView(generic.UpdateView):
         for formset in formsets.values():
             formset.save()
 
+        for idx, image in enumerate(self.object.images.all()):
+            image.display_order = idx
+            image.save()
+
         return HttpResponseRedirect(self.get_success_url())
 
     def handle_adding_child(self, parent):
@@ -407,7 +423,7 @@ class ProductCreateUpdateView(generic.UpdateView):
           to a new product creation page
         """
         msg = render_to_string(
-            'dashboard/catalogue/messages/product_saved.html',
+            'oscar/dashboard/catalogue/messages/product_saved.html',
             {
                 'product': self.object,
                 'creating': self.creating,
@@ -432,13 +448,13 @@ class ProductCreateUpdateView(generic.UpdateView):
         return self.get_url_with_querystring(url)
 
 
-class ProductDeleteView(generic.DeleteView):
+class ProductDeleteView(PartnerProductFilterMixin, generic.DeleteView):
     """
     Dashboard view to delete a product. Has special logic for deleting the
     last child product.
     Supports the permission-based dashboard.
     """
-    template_name = 'dashboard/catalogue/product_delete.html'
+    template_name = 'oscar/dashboard/catalogue/product_delete.html'
     model = Product
     context_object_name = 'product'
 
@@ -446,10 +462,10 @@ class ProductDeleteView(generic.DeleteView):
         """
         Filter products that the user doesn't have permission to update
         """
-        return filter_products(Product.objects.all(), self.request.user)
+        return self.filter_queryset(Product.objects.all())
 
     def get_context_data(self, **kwargs):
-        ctx = super(ProductDeleteView, self).get_context_data(**kwargs)
+        ctx = super().get_context_data(**kwargs)
         if self.object.is_child:
             ctx['title'] = _("Delete product variant?")
         else:
@@ -509,13 +525,13 @@ class ProductDeleteView(generic.DeleteView):
 
 
 class StockAlertListView(generic.ListView):
-    template_name = 'dashboard/catalogue/stockalert_list.html'
+    template_name = 'oscar/dashboard/catalogue/stockalert_list.html'
     model = StockAlert
     context_object_name = 'alerts'
     paginate_by = settings.OSCAR_STOCK_ALERTS_PER_PAGE
 
     def get_context_data(self, **kwargs):
-        ctx = super(StockAlertListView, self).get_context_data(**kwargs)
+        ctx = super().get_context_data(**kwargs)
         ctx['form'] = self.form
         ctx['description'] = self.description
         return ctx
@@ -534,7 +550,7 @@ class StockAlertListView(generic.ListView):
 
 
 class CategoryListView(SingleTableView):
-    template_name = 'dashboard/catalogue/category_list.html'
+    template_name = 'oscar/dashboard/catalogue/category_list.html'
     table_class = CategoryTable
     context_table_name = 'categories'
 
@@ -542,13 +558,13 @@ class CategoryListView(SingleTableView):
         return Category.get_root_nodes()
 
     def get_context_data(self, *args, **kwargs):
-        ctx = super(CategoryListView, self).get_context_data(*args, **kwargs)
+        ctx = super().get_context_data(*args, **kwargs)
         ctx['child_categories'] = Category.get_root_nodes()
         return ctx
 
 
 class CategoryDetailListView(SingleTableMixin, generic.DetailView):
-    template_name = 'dashboard/catalogue/category_list.html'
+    template_name = 'oscar/dashboard/catalogue/category_list.html'
     model = Category
     context_object_name = 'category'
     table_class = CategoryTable
@@ -558,8 +574,7 @@ class CategoryDetailListView(SingleTableMixin, generic.DetailView):
         return self.object.get_children()
 
     def get_context_data(self, *args, **kwargs):
-        ctx = super(CategoryDetailListView, self).get_context_data(*args,
-                                                                   **kwargs)
+        ctx = super().get_context_data(*args, **kwargs)
         ctx['child_categories'] = self.object.get_children()
         ctx['ancestors'] = self.object.get_ancestors_and_self()
         return ctx
@@ -577,61 +592,64 @@ class CategoryListMixin(object):
 
 
 class CategoryCreateView(CategoryListMixin, generic.CreateView):
-    template_name = 'dashboard/catalogue/category_form.html'
+    template_name = 'oscar/dashboard/catalogue/category_form.html'
     model = Category
     form_class = CategoryForm
 
     def get_context_data(self, **kwargs):
-        ctx = super(CategoryCreateView, self).get_context_data(**kwargs)
+        ctx = super().get_context_data(**kwargs)
         ctx['title'] = _("Add a new category")
         return ctx
 
     def get_success_url(self):
         messages.info(self.request, _("Category created successfully"))
-        return super(CategoryCreateView, self).get_success_url()
+        return super().get_success_url()
 
     def get_initial(self):
         # set child category if set in the URL kwargs
-        initial = super(CategoryCreateView, self).get_initial()
+        initial = super().get_initial()
         if 'parent' in self.kwargs:
             initial['_ref_node_id'] = self.kwargs['parent']
         return initial
 
 
 class CategoryUpdateView(CategoryListMixin, generic.UpdateView):
-    template_name = 'dashboard/catalogue/category_form.html'
+    template_name = 'oscar/dashboard/catalogue/category_form.html'
     model = Category
     form_class = CategoryForm
 
     def get_context_data(self, **kwargs):
-        ctx = super(CategoryUpdateView, self).get_context_data(**kwargs)
+        ctx = super().get_context_data(**kwargs)
         ctx['title'] = _("Update category '%s'") % self.object.name
         return ctx
 
     def get_success_url(self):
         messages.info(self.request, _("Category updated successfully"))
-        return super(CategoryUpdateView, self).get_success_url()
+        action = self.request.POST.get('action')
+        if action == 'continue':
+            return reverse('dashboard:catalogue-category-update', kwargs={"pk": self.object.id})
+        return super().get_success_url()
 
 
 class CategoryDeleteView(CategoryListMixin, generic.DeleteView):
-    template_name = 'dashboard/catalogue/category_delete.html'
+    template_name = 'oscar/dashboard/catalogue/category_delete.html'
     model = Category
 
     def get_context_data(self, *args, **kwargs):
-        ctx = super(CategoryDeleteView, self).get_context_data(*args, **kwargs)
+        ctx = super().get_context_data(*args, **kwargs)
         ctx['parent'] = self.object.get_parent()
         return ctx
 
     def get_success_url(self):
         messages.info(self.request, _("Category deleted successfully"))
-        return super(CategoryDeleteView, self).get_success_url()
+        return super().get_success_url()
 
 
 class ProductLookupView(ObjectLookupView):
     model = Product
 
     def get_queryset(self):
-        return self.model.browsable.all()
+        return self.model.objects.browsable().all()
 
     def lookup_filter(self, qs, term):
         return qs.filter(Q(title__icontains=term)
@@ -640,7 +658,7 @@ class ProductLookupView(ObjectLookupView):
 
 class ProductClassCreateUpdateView(generic.UpdateView):
 
-    template_name = 'dashboard/catalogue/product_class_form.html'
+    template_name = 'oscar/dashboard/catalogue/product_class_form.html'
     model = ProductClass
     form_class = ProductClassForm
     product_attributes_formset = ProductAttributesFormSet
@@ -689,7 +707,7 @@ class ProductClassCreateUpdateView(generic.UpdateView):
     form_valid = form_invalid = process_all_forms
 
     def get_context_data(self, *args, **kwargs):
-        ctx = super(ProductClassCreateUpdateView, self).get_context_data(
+        ctx = super().get_context_data(
             *args, **kwargs)
 
         if "attributes_formset" not in ctx:
@@ -733,25 +751,23 @@ class ProductClassUpdateView(ProductClassCreateUpdateView):
 
 
 class ProductClassListView(generic.ListView):
-    template_name = 'dashboard/catalogue/product_class_list.html'
+    template_name = 'oscar/dashboard/catalogue/product_class_list.html'
     context_object_name = 'classes'
     model = ProductClass
 
     def get_context_data(self, *args, **kwargs):
-        ctx = super(ProductClassListView, self).get_context_data(*args,
-                                                                 **kwargs)
+        ctx = super().get_context_data(*args, **kwargs)
         ctx['title'] = _("Product Types")
         return ctx
 
 
 class ProductClassDeleteView(generic.DeleteView):
-    template_name = 'dashboard/catalogue/product_class_delete.html'
+    template_name = 'oscar/dashboard/catalogue/product_class_delete.html'
     model = ProductClass
     form_class = ProductClassForm
 
     def get_context_data(self, *args, **kwargs):
-        ctx = super(ProductClassDeleteView, self).get_context_data(*args,
-                                                                   **kwargs)
+        ctx = super().get_context_data(*args, **kwargs)
         ctx['title'] = _("Delete product type '%s'") % self.object.name
         product_count = self.object.products.count()
 
@@ -770,7 +786,7 @@ class ProductClassDeleteView(generic.DeleteView):
 
 class AttributeOptionGroupCreateUpdateView(generic.UpdateView):
 
-    template_name = 'dashboard/catalogue/attribute_option_group_form.html'
+    template_name = 'oscar/dashboard/catalogue/attribute_option_group_form.html'
     model = AttributeOptionGroup
     form_class = AttributeOptionGroupForm
     attribute_option_formset = AttributeOptionFormSet
@@ -798,8 +814,10 @@ class AttributeOptionGroupCreateUpdateView(generic.UpdateView):
     def forms_valid(self, form, attribute_option_formset):
         form.save()
         attribute_option_formset.save()
-
-        return HttpResponseRedirect(self.get_success_url())
+        if self.is_popup:
+            return self.popup_response(form.instance)
+        else:
+            return HttpResponseRedirect(self.get_success_url())
 
     def forms_invalid(self, form, attribute_option_formset):
         messages.error(self.request,
@@ -819,7 +837,7 @@ class AttributeOptionGroupCreateUpdateView(generic.UpdateView):
     form_valid = form_invalid = process_all_forms
 
     def get_context_data(self, **kwargs):
-        ctx = super(AttributeOptionGroupCreateUpdateView, self).get_context_data(**kwargs)
+        ctx = super().get_context_data(**kwargs)
         ctx.setdefault("attribute_option_formset", self.attribute_option_formset(instance=self.object))
         ctx["title"] = self.get_title()
         return ctx
@@ -842,8 +860,7 @@ class AttributeOptionGroupCreateView(PopUpWindowCreateMixin, AttributeOptionGrou
         return _("Add a new Attribute Option Group")
 
     def get_success_url(self):
-        if not self.is_popup:
-            messages.info(self.request, _("Attribute Option Group created successfully"))
+        self.add_success_message(_("Attribute Option Group created successfully"))
         url = reverse("dashboard:catalogue-attribute-option-group-list")
         return self.get_url_with_querystring(url)
 
@@ -860,33 +877,32 @@ class AttributeOptionGroupUpdateView(PopUpWindowUpdateMixin, AttributeOptionGrou
         return _("Update Attribute Option Group '%s'") % self.object.name
 
     def get_success_url(self):
-        if not self.is_popup:
-            messages.info(self.request, _("Attribute Option Group updated successfully"))
+        self.add_success_message(_("Attribute Option Group updated successfully"))
         url = reverse("dashboard:catalogue-attribute-option-group-list")
         return self.get_url_with_querystring(url)
 
 
 class AttributeOptionGroupListView(SingleTableView):
 
-    template_name = 'dashboard/catalogue/attribute_option_group_list.html'
+    template_name = 'oscar/dashboard/catalogue/attribute_option_group_list.html'
     model = AttributeOptionGroup
     table_class = AttributeOptionGroupTable
     context_table_name = 'attribute_option_groups'
 
     def get_context_data(self, **kwargs):
-        ctx = super(AttributeOptionGroupListView, self).get_context_data(**kwargs)
+        ctx = super().get_context_data(**kwargs)
         ctx['querystring'] = self.request.GET.urlencode()
         return ctx
 
 
 class AttributeOptionGroupDeleteView(PopUpWindowDeleteMixin, generic.DeleteView):
 
-    template_name = 'dashboard/catalogue/attribute_option_group_delete.html'
+    template_name = 'oscar/dashboard/catalogue/attribute_option_group_delete.html'
     model = AttributeOptionGroup
     form_class = AttributeOptionGroupForm
 
     def get_context_data(self, **kwargs):
-        ctx = super(AttributeOptionGroupDeleteView, self).get_context_data(**kwargs)
+        ctx = super().get_context_data(**kwargs)
 
         ctx['title'] = _("Delete Attribute Option Group '%s'") % self.object.name
 
@@ -914,7 +930,104 @@ class AttributeOptionGroupDeleteView(PopUpWindowDeleteMixin, generic.DeleteView)
         return "?".join(url_parts)
 
     def get_success_url(self):
-        if not self.is_popup:
-            messages.info(self.request, _("Attribute Option Group deleted successfully"))
+        self.add_success_message(_("Attribute Option Group deleted successfully"))
         url = reverse("dashboard:catalogue-attribute-option-group-list")
         return self.get_url_with_querystring(url)
+
+
+class OptionListView(SingleTableView):
+
+    template_name = 'oscar/dashboard/catalogue/option_list.html'
+    model = Option
+    table_class = OptionTable
+    context_table_name = 'options'
+
+
+class OptionCreateUpdateView(generic.UpdateView):
+
+    template_name = 'oscar/dashboard/catalogue/option_form.html'
+    model = Option
+    form_class = OptionForm
+
+    def form_valid(self, form):
+        self.object = form.save()
+        if self.is_popup:
+            return self.popup_response(form.instance)
+        else:
+            return HttpResponseRedirect(self.get_success_url())
+
+    def get_context_data(self, **kwargs):
+        ctx = super().get_context_data(**kwargs)
+        ctx['title'] = self.get_title()
+        return ctx
+
+    def form_invalid(self, form):
+        messages.error(
+            self.request,
+            _("Your submitted data was not valid - please correct the errors below")
+        )
+        return super().form_invalid(form)
+
+
+class OptionCreateView(PopUpWindowCreateMixin, OptionCreateUpdateView):
+
+    creating = True
+
+    def get_object(self):
+        return None
+
+    def get_title(self):
+        return _("Add a new Option")
+
+    def get_success_url(self):
+        self.add_success_message(_("Option created successfully"))
+        return reverse("dashboard:catalogue-option-list")
+
+
+class OptionUpdateView(PopUpWindowUpdateMixin, OptionCreateUpdateView):
+
+    creating = False
+
+    def get_object(self):
+        attribute_option_group = get_object_or_404(Option, pk=self.kwargs['pk'])
+        return attribute_option_group
+
+    def get_title(self):
+        return _("Update Option '%s'") % self.object.name
+
+    def get_success_url(self):
+        self.add_success_message(_("Option updated successfully"))
+        return reverse("dashboard:catalogue-option-list")
+
+
+class OptionDeleteView(PopUpWindowDeleteMixin, generic.DeleteView):
+
+    template_name = 'oscar/dashboard/catalogue/option_delete.html'
+    model = Option
+
+    def get_context_data(self, **kwargs):
+        ctx = super().get_context_data(**kwargs)
+
+        ctx['title'] = _("Delete Option '%s'") % self.object.name
+
+        products = self.object.product_set.count()
+        product_classes = self.object.productclass_set.count()
+        if any([products, product_classes]):
+            ctx['disallow'] = True
+            ctx['title'] = _("Unable to delete '%s'") % self.object.name
+            if products:
+                messages.error(
+                    self.request,
+                    _("%i products are still assigned to this option") % products
+                )
+            if product_classes:
+                messages.error(
+                    self.request,
+                    _("%i product classes are still assigned to this option") % product_classes
+                )
+
+        return ctx
+
+    def get_success_url(self):
+        self.add_success_message(_("Option deleted successfully"))
+        return reverse("dashboard:catalogue-option-list")
